j\_chess\_lib package
=====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   j_chess_lib.ai
   j_chess_lib.client
   j_chess_lib.communication

Submodules
----------

j\_chess\_lib.main module
-------------------------

.. automodule:: j_chess_lib.main
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: j_chess_lib
   :members:
   :undoc-members:
   :show-inheritance:
